@@ -21,6 +21,7 @@ import logging
 import os
 import os.path
 import requests
+import sys
 
 import saunter.ConfigWrapper
 try:
@@ -39,10 +40,12 @@ except ImportError as e:
 from selenium.webdriver.common.by import By
 from selenium.common.exceptions import WebDriverException
 from selenium.common.exceptions import TimeoutException
+from saunter.exceptions import ProfileNotFound
 from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from saunter.testcase.base import BaseTestCase
 from saunter.SaunterWebDriver import SaunterWebDriver
+from selenium.webdriver import FirefoxProfile
 import py.test
 from _pytest.mark import MarkInfo
 
@@ -90,6 +93,22 @@ class SaunterTestCase(BaseTestCase):
 
         self.current_method_name = method.__name__
 
+        browser = self.cf.get("Selenium", "browser")
+        if browser[0] == "*":
+            browser = browser[1:]
+
+        profile = None
+        if browser == 'firefox':
+            if self.cf.has_option("Selenium", "profile-%s" % sys.platform):
+                profile_path = os.path.join(self.cf.get("Saunter", "base"), 'support', 'profiles', self.cf.get("Selenium", "profile-%s" % sys.platform))
+            elif self.cf.has_option("Selenium", "profile"):
+                profile_path = os.path.join(self.cf.get("Saunter", "base"), 'support', 'profiles', self.cf.get("Selenium", "profile"))
+            
+            if os.path.isdir(profile_path):
+                profile = FirefoxProfile(profile_path)
+            else:
+                raise ProfileNotFound("Profile not found at %s" % profile_path)
+
         if self.cf.getboolean("SauceLabs", "ondemand"):
             desired_capabilities = {
                 "platform": self.cf.get("SauceLabs", "os"),
@@ -101,11 +120,13 @@ class SaunterTestCase(BaseTestCase):
                 desired_capabilities["browserName"] = desired_capabilities["browserName"][1:]
             if desired_capabilities["platform"] in os_map:
                 desired_capabilities["platform"] = os_map[desired_capabilities["platform"]]
+
+            if self.cf.has_option("SauceLabs", "selenium_version"):
+                desired_capabilities['selenium-version'] = self.cf.get('SauceLabs', 'selenium_version')
+
             command_executor = "http://%s:%s@ondemand.saucelabs.com:80/wd/hub" % (self.cf.get("SauceLabs", "username"), self.cf.get("SauceLabs", "key"))
         else:
-            browser = self.cf.get("Selenium", "browser")
-            if browser[0] == "*":
-                browser = browser[1:]
+
             if browser == "chrome":
                 os.environ["webdriver.chrome.driver"] = self.cf.get("Selenium", "chromedriver_path")
             desired_capabilities = capabilities_map[browser]
@@ -123,7 +144,8 @@ class SaunterTestCase(BaseTestCase):
                         desired_capabilities["version"] = str(self.cf.get("Grid", "browser_version"))
 
             command_executor = "http://%s:%s/wd/hub" % (self.cf.get("Selenium", "server_host"), self.cf.get("Selenium", "server_port"))
-        self.driver = WebDriver(desired_capabilities = desired_capabilities, command_executor = command_executor)
+
+        self.driver = WebDriver(desired_capabilities = desired_capabilities, command_executor = command_executor, browser_profile=profile)
 
         self.verificationErrors = []
         self.matchers = Matchers(self.driver, self.verificationErrors)
@@ -152,7 +174,16 @@ class SaunterTestCase(BaseTestCase):
                 self.driver.get_screenshot_as_file(os.path.join(method_dir, str(self._screenshot_number).zfill(3) + ".png"))
                 self._screenshot_number = self._screenshot_number + 1
 
+                if self.config.has_option("Saunter", "jenkins"):
+                    if self.cf.getboolean("Saunter", "jenkins"):
+                        sys.stdout.write(os.linesep + "[[ATTACHMENT|%s]]" % image_path + os.linesep)
+
     def take_named_screenshot(self, name):
         method_dir = self._screenshot_prep_dirs()
 
-        self.driver.get_screenshot_as_file(os.path.join(method_dir, str(name) + ".png"))
+        image_path = os.path.join(method_dir, str(name) + ".png")
+        self.driver.get_screenshot_as_file(image_path)
+
+        if self.config.has_option("Saunter", "jenkins"):
+            if self.cf.getboolean("Saunter", "jenkins"):
+                sys.stdout.write(os.linesep + "[[ATTACHMENT|%s]]" % image_path + os.linesep)
